@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from datetime import datetime
-from math import floor, ceil
+from math import floor
 
 from kinetick.bot import Bot
 from kinetick.models import Position
@@ -50,10 +50,10 @@ class RiskAssessor(Borg):
 
     def availableMarginHandler(self, update, context):
         msg = "```\n" \
-              "Available margin: {} \n" \
+              "Available margin: {:.2f} \n" \
               "Active Trades: {} \n" \
-              "Available capital: {} \n" \
-              "PNL: {} \n" \
+              "Available capital: {:.2f} \n" \
+              "PNL: {:.2f} \n" \
               "Win Trades: {} \n" \
               "Loss Trades: {} \n" \
               "```".format(self.available_margin, len(self.active_positions),
@@ -64,18 +64,21 @@ class RiskAssessor(Borg):
     def get_default_instance():
         return RiskAssessor(initial_capital=6000, max_trades=2, initial_margin=6000, risk2reward=1.3)
 
-    def reset(self):
+    def reset(self, update=None, ctx=None, **kwargs):
         self.capital = self.initial_capital
         self.available_margin = self.initial_margin
         self.active_positions.clear()
         self.pnl = 0
         self.win_trades = 0
         self.loss_trades = 0
+        if update is not None:
+            update.message.reply_text("RMS has been reset.")
 
     def _should_trade(self, entry_price, stop_loss, quantity=None):
         spread = abs(entry_price - stop_loss)
         spread = 5 * round(spread / 5, 2)
-        _quantity = quantity or floor(max(1, int(self.risk_per_trade / spread)))
+        maxsize = floor(max(1, int(self.risk_per_trade / spread)))
+        _quantity = quantity or maxsize
         margin = _quantity * spread
         should_trade = True
         reason = None
@@ -92,10 +95,10 @@ class RiskAssessor(Borg):
         elif (entry_price * _quantity) >= self.capital:
             should_trade = False
             reason = f'Insufficient Capital. required: {entry_price * _quantity} available: {self.capital}'
-        elif quantity and int(quantity) > floor(max(1, int(self.risk_per_trade / spread))):
+        elif quantity and int(quantity) > maxsize:
             should_trade = False
             reason = f'given quantity: {quantity} exceeds risk per trade: {self.risk_per_trade}, ' \
-                     f'max allowed quantity {_quantity}'
+                     f'max allowed quantity {maxsize}'
 
         quantity = _quantity
         return should_trade, spread, quantity, reason
@@ -110,7 +113,7 @@ class RiskAssessor(Borg):
         """
         should_trade, spread, quantity, reason = self._should_trade(entry_price, stop_loss, quantity=quantity)
         if not should_trade:
-            raise Exception(f'Trade can not be made voids risk parameters {reason}')
+            raise Exception(f'Trade can not be made voids risk parameters. {reason}')
 
         direction = "LONG" if stop_loss < entry_price else "SHORT"
         target = 5 * round((spread * self.risk2reward) / 5, 2)
@@ -128,7 +131,7 @@ class RiskAssessor(Borg):
         should_trade, spread, quantity, reason = self._should_trade(position.entry_price, position.stop,
                                                                     quantity=position.quantity)
         if not should_trade:
-            raise Exception(f'Trade can not be made void risk margins {reason}')
+            raise Exception(f'Trade can not be made voids rms parameters. {reason}')
         self.active_positions.append(position)
         self.available_margin = self.available_margin - spread * quantity
         self.capital = self.capital - (position.entry_price * quantity)
@@ -138,15 +141,17 @@ class RiskAssessor(Borg):
     def exit_position(self, position):
         if position.exit_time is None:
             position.exit_time = datetime.now()
-        if position.exit_price is None:
-            raise Exception("Trade exit_price is not provided")
 
         pnl = position.pnl()
 
-        self.available_margin = round(self.available_margin + pnl, 2) if pnl > 0 else self.available_margin
-        # if pnl is -ve then it would already be subtracted when entering the trade.
-        self.capital = self.capital + (position.entry_price * position.quantity) + pnl
+        # reclaim margin
+        spread = abs(position.entry_price - position.stop)
+        spread = 5 * round(spread / 5, 2)
+        self.available_margin += spread * position.quantity + pnl
+        self.available_margin = self.available_margin if self.available_margin < self.initial_margin \
+            else self.initial_margin
         # reclaim the capital deployed in trade
+        self.capital += (position.entry_price * position.quantity) + pnl
         self.pnl += pnl
         if pnl > 0:
             self.win_trades += 1
@@ -156,6 +161,4 @@ class RiskAssessor(Borg):
         index = self.active_positions.index(position)
         del self.active_positions[index]
 
-        position.realized_pnl = round(pnl * 2, 2) / 2
-
         return position
